@@ -14,7 +14,7 @@ def generate(args, pkgname):
     # Rewrite APKBUILD
     fields = {
         "pkgname": pkgname,
-        "pkgdesc": "Tools necessary to build programs for " + arch + " targets",
+        "pkgdesc": f"Tools necessary to build programs for {arch} targets",
         "arch": args.arch_native,
         "makedepends_build": "",
         "makedepends_host": "",
@@ -50,5 +50,8 @@ def generate(args, pkgname):
         "gold": None,
     }
 
+    replace_simple = {"\tsubpackages=*": "\tsubpackages=\"\""}
+
     pmb.aportgen.core.rewrite(args, pkgname, "main/binutils", fields,
-                              "binutils", replace_functions, remove_indent=8)
+                              "binutils", replace_functions, replace_simple,
+                              remove_indent=8)
