@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import glob
+import json
 import os
 import shutil
 
@@ -10,6 +11,7 @@ import pmb.config
 import pmb.config.pmaports
 import pmb.helpers.cli
 import pmb.helpers.devices
+import pmb.helpers.http
 import pmb.helpers.logging
 import pmb.helpers.other
 import pmb.helpers.run
@@ -26,8 +28,8 @@ def require_programs():
             missing.append(program)
     if missing:
         raise RuntimeError("Can't find all programs required to run"
-                           " pmbootstrap. Please install first: " +
-                           ", ".join(missing))
+                           " pmbootstrap. Please install first:"
+                           f" {', '.join(missing)}")
 
 
 def ask_for_work_path(args):
@@ -51,7 +53,7 @@ def ask_for_work_path(args):
 
             # Work must not be inside the pmbootstrap path
             if (work == pmb.config.pmb_src or
-                    work.startswith(pmb.config.pmb_src + "/")):
+                    work.startswith(f"{pmb.config.pmb_src}/")):
                 logging.fatal("ERROR: The work path must not be inside the"
                               " pmbootstrap path. Please specify another"
                               " location.")
@@ -64,12 +66,12 @@ def ask_for_work_path(args):
             if not os.listdir(work):
                 # Directory is empty, either because we just created it or
                 # because user created it before running pmbootstrap init
-                with open(work + "/version", "w") as handle:
-                    handle.write(str(pmb.config.work_version) + "\n")
+                with open(f"{work}/version", "w") as handle:
+                    handle.write(f"{pmb.config.work_version}\n")
 
             # Create cache_git dir, so it is owned by the host system's user
             # (otherwise pmb.helpers.mount.bind would create it as root)
-            os.makedirs(work + "/cache_git", 0o700, True)
+            os.makedirs(f"{work}/cache_git", 0o700, True)
             return (work, exists)
         except OSError:
             logging.fatal("ERROR: Could not create this folder, or write"
@@ -112,12 +114,29 @@ def ask_for_channel(args):
 def ask_for_ui(args, device):
     info = pmb.parse.deviceinfo(args, device)
     ui_list = pmb.helpers.ui.list(args, info["arch"])
-    logging.info("Available user interfaces (" +
-                 str(len(ui_list) - 1) + "): ")
+    hidden_ui_count = 0
+    device_is_accelerated = info.get("gpu_accelerated") == "true"
+    if not device_is_accelerated:
+        for i in reversed(range(len(ui_list))):
+            pkgname = f"postmarketos-ui-{ui_list[i][0]}"
+            apkbuild = pmb.helpers.pmaports.get(args, pkgname,
+                                                subpackages=False,
+                                                must_exist=False)
+            if apkbuild and "pmb:gpu-accel" in apkbuild["options"]:
+                ui_list.pop(i)
+                hidden_ui_count += 1
+
+    logging.info(f"Available user interfaces ({len(ui_list) - 1}): ")
     ui_completion_list = []
     for ui in ui_list:
-        logging.info("* " + ui[0] + ": " + ui[1])
+        logging.info(f"* {ui[0]}: {ui[1]}")
         ui_completion_list.append(ui[0])
+    if hidden_ui_count > 0:
+        logging.info(f"NOTE: {hidden_ui_count} user interfaces are not"
+                     " available. If device supports GPU acceleration,"
+                     " set \"deviceinfo_gpu_accelerated\" to make UIs"
+                     " available. See: <https://wiki.postmarketos.org/wiki/"
+                     "Deviceinfo_reference")
     while True:
         ret = pmb.helpers.cli.ask(args, "User interface", None, args.ui, True,
                                   complete=ui_completion_list)
@@ -128,17 +147,17 @@ def ask_for_ui(args, device):
 
 
 def ask_for_ui_extras(args, ui):
-    apkbuild = pmb.helpers.pmaports.get(args, "postmarketos-ui-" + ui,
+    apkbuild = pmb.helpers.pmaports.get(args, f"postmarketos-ui-{ui}",
                                         subpackages=False, must_exist=False)
     if not apkbuild:
         return False
 
-    extra = apkbuild["subpackages"].get("postmarketos-ui-" + ui + "-extras")
+    extra = apkbuild["subpackages"].get(f"postmarketos-ui-{ui}-extras")
     if extra is None:
         return False
 
-    logging.info("This user interface has an extra package: " +
-                 extra["pkgdesc"])
+    logging.info("This user interface has an extra package:"
+                 f" {extra['pkgdesc']}")
 
     return pmb.helpers.cli.confirm(args, "Enable this package?",
                                    default=args.ui_extras)
@@ -149,8 +168,8 @@ def ask_for_keymaps(args, device):
     if "keymaps" not in info or info["keymaps"].strip() == "":
         return ""
     options = info["keymaps"].split(' ')
-    logging.info("Available keymaps for device (" + str(len(options)) +
-                 "): " + ", ".join(options))
+    logging.info(f"Available keymaps for device ({len(options)}): "
+                 f"{', '.join(options)}")
     if args.keymap == "":
         args.keymap = options[0]
 
@@ -179,7 +198,7 @@ def ask_for_timezone(args):
                 except:
                     pass
         if tz:
-            logging.info("Your host timezone: " + tz)
+            logging.info(f"Your host timezone: {tz}")
             if pmb.helpers.cli.confirm(args,
                                        "Use this timezone instead of GMT?",
                                        default="y"):
@@ -218,9 +237,9 @@ def ask_for_device_kernel(args, device):
                      " downstream kernels.")
 
     # List kernels
-    logging.info("Available kernels (" + str(len(kernels)) + "):")
+    logging.info(f"Available kernels ({len(kernels)}):")
     for type in sorted(kernels.keys()):
-        logging.info("* " + type + ": " + kernels[type])
+        logging.info(f"* {type}: {kernels[type]}")
     while True:
         ret = pmb.helpers.cli.ask(args, "Kernel", None, default, True,
                                   complete=kernels)
@@ -252,7 +271,7 @@ def ask_for_device_nonfree(args, device):
     # Only run when there is a "nonfree" subpackage
     nonfree_found = False
     for subpackage in apkbuild["subpackages"].keys():
-        if subpackage.startswith("device-" + device + "-nonfree"):
+        if subpackage.startswith(f"device-{device}-nonfree"):
             nonfree_found = True
     if not nonfree_found:
         return ret
@@ -266,13 +285,13 @@ def ask_for_device_nonfree(args, device):
 
     # Ask for firmware and userland individually
     for type in ["firmware", "userland"]:
-        subpkgname = "device-" + device + "-nonfree-" + type
+        subpkgname = f"device-{device}-nonfree-{type}"
         subpkg = apkbuild["subpackages"].get(subpkgname, {})
         if subpkg is None:
             raise RuntimeError("Cannot find subpackage function for "
                                f"{subpkgname}")
         if subpkg:
-            logging.info(subpkgname + ": " + subpkg["pkgdesc"])
+            logging.info(f"{subpkgname}: {subpkg['pkgdesc']}")
             ret[type] = pmb.helpers.cli.confirm(args, "Enable this package?",
                                                 default=ret[type])
     return ret
@@ -282,8 +301,7 @@ def ask_for_device(args):
     vendors = sorted(pmb.helpers.devices.list_vendors(args))
     logging.info("Choose your target device vendor (either an "
                  "existing one, or a new one for porting).")
-    logging.info("Available vendors (" + str(len(vendors)) + "): " +
-                 ", ".join(vendors))
+    logging.info(f"Available vendors ({len(vendors)}): {', '.join(vendors)}")
 
     current_vendor = None
     current_codename = None
@@ -318,7 +336,7 @@ def ask_for_device(args):
                                        current_codename, False, r"[a-z0-9]+",
                                        codenames)
 
-        device = vendor + '-' + codename
+        device = f"{vendor}-{codename}"
         device_path = pmb.helpers.devices.find_path(args, device, 'deviceinfo')
         device_exists = device_path is not None
         if not device_exists:
@@ -327,18 +345,18 @@ def ask_for_device(args):
                     "This device does not exist anymore, check"
                     " <https://postmarketos.org/renamed>"
                     " to see if it was renamed")
-            logging.info("You are about to do a new device port for '" +
-                         device + "'.")
+            logging.info("You are about to do"
+                         f" a new device port for '{device}'.")
             if not pmb.helpers.cli.confirm(args, default=True):
                 current_vendor = vendor
                 continue
 
             # New port creation confirmed
             logging.info("Generating new aports for: {}...".format(device))
-            pmb.aportgen.generate(args, "device-" + device)
-            pmb.aportgen.generate(args, "linux-" + device)
+            pmb.aportgen.generate(args, f"device-{device}")
+            pmb.aportgen.generate(args, f"linux-{device}")
         elif "/unmaintained/" in device_path:
-            apkbuild = device_path[:-len("deviceinfo")] + 'APKBUILD'
+            apkbuild = f"{device_path[:-len('deviceinfo')]}APKBUILD"
             unmaintained = pmb.parse._apkbuild.unmaintained(apkbuild)
             logging.info(f"WARNING: {device} is unmaintained: {unmaintained}")
             if not pmb.helpers.cli.confirm(args):
@@ -357,7 +375,8 @@ def ask_for_additional_options(args, cfg):
                  f" boot partition size: {args.boot_size} MB,"
                  f" parallel jobs: {args.jobs},"
                  f" ccache per arch: {args.ccache_size},"
-                 f" sudo timer: {args.sudo_timer}")
+                 f" sudo timer: {args.sudo_timer},"
+                 f" mirror: {','.join(args.mirrors_postmarketos)}")
 
     if not pmb.helpers.cli.confirm(args, "Change them?",
                                    default=False):
@@ -411,6 +430,72 @@ def ask_for_additional_options(args, cfg):
                                      default=args.sudo_timer)
     cfg["pmbootstrap"]["sudo_timer"] = str(answer)
 
+    # Mirrors
+    # prompt for mirror change
+    logging.info("Selected mirror:"
+                 f" {','.join(args.mirrors_postmarketos)}")
+    if pmb.helpers.cli.confirm(args, "Change mirror?", default=False):
+        mirrors = ask_for_mirror(args)
+        cfg["pmbootstrap"]["mirrors_postmarketos"] = ",".join(mirrors)
+
+
+def ask_for_mirror(args):
+    regex = "^[1-9][0-9]*$"  # single non-zero number only
+
+    json_path = pmb.helpers.http.download(
+        args, "https://postmarketos.org/mirrors.json", "pmos_mirrors",
+        cache=False)
+    with open(json_path, "rt") as handle:
+        s = handle.read()
+
+    logging.info("List of available mirrors:")
+    mirrors = json.loads(s)
+    keys = mirrors.keys()
+    i = 1
+    for key in keys:
+        logging.info(f"[{i}]\t{key} ({mirrors[key]['location']})")
+        i += 1
+
+    urls = []
+    for key in keys:
+        # accept only http:// or https:// urls
+        http_count = 0  # remember if we saw any http:// only URLs
+        link_list = []
+        for k in mirrors[key]["urls"]:
+            if k.startswith("http"):
+                link_list.append(k)
+            if k.startswith("http://"):
+                http_count += 1
+        # remove all https urls if there is more that one URL and one of
+        #     them was http://
+        if http_count > 0 and len(link_list) > 1:
+            link_list = [k for k in link_list if not k.startswith("https")]
+        if len(link_list) > 0:
+            urls.append(link_list[0])
+
+    mirror_indexes = []
+    for mirror in args.mirrors_postmarketos:
+        for i in range(len(urls)):
+            if urls[i] == mirror:
+                mirror_indexes.append(str(i + 1))
+                break
+
+    mirrors_list = []
+    # require one valid mirror index selected by user
+    while len(mirrors_list) != 1:
+        answer = pmb.helpers.cli.ask(args, "Select a mirror", None,
+                                     ",".join(mirror_indexes),
+                                     validation_regex=regex)
+        mirrors_list = []
+        for i in answer.split(","):
+            idx = int(i) - 1
+            if 0 <= idx < len(urls):
+                mirrors_list.append(urls[idx])
+        if len(mirrors_list) != 1:
+            logging.info("You must select one valid mirror!")
+
+    return mirrors_list
+
 
 def ask_for_hostname(args, device):
     while True:
@@ -447,6 +532,7 @@ def ask_for_locale(args):
     locales = pmb.config.locales
     logging.info(f"Available locales ({len(locales)}): {', '.join(locales)}")
     return pmb.helpers.cli.ask(args, "Choose default locale for installation",
+                               choices=None,
                                default=args.locale,
                                lowercase_answer=False,
                                validation_regex="|".join(locales),
