@@ -439,6 +439,10 @@ def arguments_kconfig(subparser):
                        " options needed for anbox too")
     check.add_argument("--nftables", action="store_true", help="check"
                        " options needed for nftables too")
+    check.add_argument("--containers", action="store_true",
+                       help="check options needed for containers too")
+    check.add_argument("--zram", action="store_true", help="check"
+                       " options needed for zram support too")
     check_package = check.add_argument("package", default="", nargs='?')
     if argcomplete:
         check_package.completer = kernel_completer
@@ -529,7 +533,7 @@ def arguments():
     parser.add_argument("-mp", "--mirror-pmOS", dest="mirrors_postmarketos",
                         help="postmarketOS mirror, disable with: -mp='',"
                              " specify multiple with: -mp='one' -mp='two',"
-                             " default: " + ", ".join(mirrors_pmos_default),
+                             f" default: {mirrors_pmos_default}",
                         metavar="URL", action="append", default=[])
     parser.add_argument("-m", "--mirror-alpine", dest="mirror_alpine",
                         help="Alpine Linux mirror, default: " +
